=============
zedsuite
=============
Pure python implementations of ZeD Codebase compiled with Cython

#############
Installing
#############
::

    $ pip install zedsuite

#############
Usage
#############
See `notebooks/ <https://github.com/zeroknowledgediscovery/python_implementations_/tree/main/notebooks>`_ ::

    from zedsuite.genesess import GenESeSS
    from zedsuite.quantizer import Quantizer
    from zedsuite.zutil import Llk, Lsmash
